## Introduction

The **meta Hi-C pipeline** is regrouping different Hi-C pipelines for Analysis of Chromosome Conformation Capture data.

The pipeline is built using [Nextflow](https://www.nextflow.io), a workflow tool to run tasks across multiple compute infrastructures in a very portable manner. It uses Docker/Singularity containers making installation trivial and results highly reproducible. The [Nextflow DSL2](https://www.nextflow.io/docs/latest/dsl2.html) implementation of this pipeline uses one container per process which makes it much easier to maintain and update software dependencies.

The pipeline is based on the [nf-core/hic](https://github.com/nf-core/hic) pipeline and the [hicstuff](https://github.com/koszullab/hicstuff) pipeline.
It is split into two workflows for now, named `hicpro` and `hicstuff`.

## Workflow summary (hicpro)

1. Read QC ([`FastQC`](https://www.bioinformatics.babraham.ac.uk/projects/fastqc/))
2. Hi-C data processing
   1. [`HiC-Pro`](https://github.com/nservant/HiC-Pro)
      1. Mapping using a two steps strategy to rescue reads spanning the ligation
         sites ([`bowtie2`](http://bowtie-bio.sourceforge.net/bowtie2/index.shtml))
      2. Detection of valid interaction products
      3. Duplicates removal
      4. Generate raw and normalized contact maps ([`iced`](https://github.com/hiclib/iced))
3. Create genome-wide contact maps at various resolutions ([`cooler`](https://github.com/open2c/cooler))
4. Contact maps normalization using balancing algorithm ([`cooler`](https://github.com/open2c/cooler))
5. Export to various contact maps formats ([`HiC-Pro`](https://github.com/nservant/HiC-Pro), [`cooler`](https://github.com/open2c/cooler))
6. Quality controls ([`HiC-Pro`](https://github.com/nservant/HiC-Pro), [`HiCExplorer`](https://github.com/deeptools/HiCExplorer))
7. Compartments calling ([`cooltools`](https://cooltools.readthedocs.io/en/latest/))
8. TADs calling ([`HiCExplorer`](https://github.com/deeptools/HiCExplorer), [`cooltools`](https://cooltools.readthedocs.io/en/latest/))
9. Quality control report ([`MultiQC`](https://multiqc.info/))

## Workflow summary (hicstuff)
1. Hi-C data préparation
2. Processing
    1. Mapping
    2. Merge and filter
    3. Fragment attribution
    4. Matrix generation

## Usage
### Prepare the environment
If you want to run the pipeline on the PSMN, you first need to set up your [PSMN environment](https://lbmc.gitbiopages.ens-lyon.fr/biocomp/resources/psmn_cbp/) if it's not already done.

Then your going to clone this repository in your `scratch/Bio` directory or locally on your computer
```
git clone git@gitbio.ens-lyon.fr:LBMC/hub/hic.git
```
Then `cd` in the git directory
### Get started
Prepare a samplesheet with your input data that looks as follows:

`samplesheet.csv`:

```csv
sample,fastq_1,fastq_2
HIC_ES_4,SRR5339783_1.fastq.gz,SRR5339783_2.fastq.gz
```

Each row represents a pair of fastq files (paired end).
Now, you can run the pipeline using:

```bash
nextflow run main.nf \
   -profile psmn \
   --workflow <hicpro/hicstuff> \
   --input samplesheet.csv \
   --fasta <path/to/genome.fasta> \
   --outdir <OUTDIR> \
   --digestion <dpnii/hindiii/arima/mboi>
```
If your not running the pipeline on the PSMN, make sure you have Docker installed and use `-profile docker` instead.

For detailed options, please refer to the [parameter documentation](docs/usage.md).

## Pipeline output

To see the the results of a test run with a full size dataset refer to the [results](https://nf-co.re/hic/2.1.0/results/hic/results-fe4ac656317d24c37e81e7940a526ed9ea812f8e/) tab on the nf-core website pipeline page (hicpro workflow, original nf-core/hic pipeline's results).
For more details about the output files and reports, please refer to the
[output documentation](docs/output.md).

## Credits

nf-core/hic was originally written by Nicolas Servant.
hicstuff was originally written by Romain Koszul's lab.
This pipeline was modified by Mia Croiset.

## Support

For further information or help, don't hesitate to get in touch on the [Element](https://element.io/) or by email.

